import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixAutomationsActivationLogsV1ActivationSummary from './automations-activation-logs-v1-activation-summary-activation-action-summary.http.js';
/**
 * Get activation summary by automation id
 * @param automationId - Automation ID
 * @public
 * @documentationMaturity preview
 * @requiredField automationId
 * @permissionId AUTOMATIONS.ACTIVATION_SUMMARY_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @returns Activation summary per automation
 * @fqn wix.automations.activation_logs.v1.ActivationSummariesService.GetActivationSummary
 */
export async function getActivationSummary(automationId) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        automationId: automationId,
    });
    const reqOpts = ambassadorWixAutomationsActivationLogsV1ActivationSummary.getActivationSummary(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data)
            ?.activationSummary;
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { automationId: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['automationId']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/** @public
 * @documentationMaturity preview
 * @requiredField identifiers
 * @requiredField identifiers.appId
 * @requiredField identifiers.componentId
 * @permissionId AUTOMATIONS.ACTIVATION_SUMMARY_READ
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @applicableIdentity APP
 * @fqn wix.automations.activation_logs.v1.ActivationSummariesService.GetActivationSummaryByPreinstalledOrigin
 */
export async function getActivationSummaryByPreinstalledOrigin(identifiers) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        appId: identifiers?.appId,
        componentId: identifiers?.componentId,
    });
    const reqOpts = ambassadorWixAutomationsActivationLogsV1ActivationSummary.getActivationSummaryByPreinstalledOrigin(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                appId: '$[0].appId',
                componentId: '$[0].componentId',
            },
            singleArgumentUnchanged: false,
        }, ['identifiers']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * migrate activations count
 * @param metaSiteId - MetaSite ID
 * @public
 * @documentationMaturity preview
 * @requiredField metaSiteId
 * @requiredField options.activationsCount
 * @requiredField options.automationId
 * @requiredField options.lastActivatedDate
 * @permissionId AUTOMATIONS.ACTIVATION_SUMMARY_WRITE
 * @fqn wix.automations.activation_logs.v1.ActivationSummariesService.MigrateActivationsCount
 */
export async function migrateActivationsCount(metaSiteId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        metaSiteId: metaSiteId,
        automationId: options?.automationId,
        preinstalledOrigin: options?.preinstalledOrigin,
        activationsCount: options?.activationsCount,
        lastActivatedDate: options?.lastActivatedDate,
    });
    const reqOpts = ambassadorWixAutomationsActivationLogsV1ActivationSummary.migrateActivationsCount(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                metaSiteId: '$[0]',
                automationId: '$[1].automationId',
                preinstalledOrigin: '$[1].preinstalledOrigin',
                activationsCount: '$[1].activationsCount',
                lastActivatedDate: '$[1].lastActivatedDate',
            },
            singleArgumentUnchanged: false,
        }, ['metaSiteId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=automations-activation-logs-v1-activation-summary-activation-action-summary.universal.js.map